SpinServicer class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- AIDVANTAGE → String
-
final
- AMERICAN_EDUCATION_SERVICES → String
-
final
- COLLEGE_FOUNDATION_OF_NORTH_CAROLINA → String
-
final
- COMMONBOND_FIRSTMARK_SERVICES → String
-
final
- CORNERSTONE_EDUCATION_LOAN_SERVICES → String
-
final
- EARNEST → String
-
final
- EDFINANCIAL_SERVICES_FEDERAL_DIRECT_LOAN_PROGRAM → String
-
final
- FEDLOAN_SERVICING → String
-
final
- FIRSTMARK_SERVICES → String
-
final
- GRANITE_STATE_MANAGEMENT_E_RESOURCES → String
-
final
- GREAT_LAKES → String
-
final
- HEARTLAND_ECSI → String
-
final
- LENDKEY → String
-
final
- MOHELA_EDUCATION_LOAN_FINANCE → String
-
final
- MOHELA_LAUREL_ROAD → String
-
final
- MOHELA_SOFI_SERVICING → String
-
final
- NAVIENT_LOANS → String
-
final
- NAVIREFI → String
-
final
- NAVY_FEDERAL_CREDIT_UNION → String
-
final
- NELNET_EDUCATION_FINANCING → String
-
final
- OKLAHOMA_STUDENT_LOAN_AUTHORITY_DIRECT_LOAN → String
-
final
- PNC → String
-
final
- SALLIE_MAE → String
-
final
- SOFI → String
-
final
- STUB_LOAN_SERVICER_ADDITION_INFO → String
-
final
- STUB_LOAN_SERVICER_MULTI_STEP → String
-
final
- STUB_LOAN_SERVICER_SINGLE_STEP → String
-
final
- SUNTRUST → String
-
final
- UNIVERSITY_ACCOUNTING_SERVICE_LLC → String
-
final
- VERMONT_STUDENT_ASSISTANCE_CORPORATION → String
-
final
- WELLS_FARGO → String
-
final