IUseCaseAllServicers class abstract

Constructors

IUseCaseAllServicers()

Properties

allServicers ↔ RxList<Servicer>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servicer ↔ Rx<Servicer>
getter/setter pair

Methods

getAllServicers() Future<List<Servicer>>
getServicer(String servicerID) Future<Servicer>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited